@@ -37,49 +37,46 @@
 #include <pdal/DimDetail.hpp>
 #include <pdal/DimType.hpp>
 #include <pdal/Mesh.hpp>
-#include <pdal/PointContainer.hpp>
 #include <pdal/PointLayout.hpp>
-#include <pdal/PointRef.hpp>
 #include <pdal/PointTable.hpp>
-#include <pdal/util/Bounds.hpp>
+#include <pdal/PointRef.hpp>
 
 #include <memory>
 #include <queue>
 #include <set>
-#include <vector>
 #include <deque>
 
-#ifdef PDAL_COMPILER_MSVC
-#  pragma warning(disable: 4244)  // conversion from 'type1' to 'type2', possible loss of data
-#endif
-
 namespace pdal
 {
-namespace plang
-{
-    class Invocation;
-}
 
 struct PointViewLess;
 class PointView;
 class PointViewIter;
 class KD2Index;
 class KD3Index;
+class BOX2D;
+class BOX3D;
+
+struct RasterLimits;
+template <class T> class Raster;
+using Rasterd = Raster<double>;
 
 typedef std::shared_ptr<PointView> PointViewPtr;
 typedef std::set<PointViewPtr, PointViewLess> PointViewSet;
 
-class PDAL_DLL PointView : public PointContainer
+class PDAL_EXPORT PointView
 {
-    friend class plang::Invocation;
-    friend class PointIdxRef;
+    FRIEND_TEST(VoxelCenterNearestNeighborFilterTest, center);
+    friend class Stage;
+    friend class PointRef;
+    friend class PointViewIter;
     friend struct PointViewLess;
 public:
     PointView(const PointView&) = delete;
     PointView& operator=(const PointView&) = delete;
     PointView(PointTableRef pointTable);
     PointView(PointTableRef pointTable, const SpatialReference& srs);
-    virtual ~PointView();
+    ~PointView();
 
     PointViewIter begin();
     PointViewIter end();
@@ -96,14 +93,13 @@ public:
     inline void appendPoint(const PointView& buffer, PointId id);
     void append(const PointView& buf)
     {
-        // We use size() instead of the index end because temp points
-        // might have been placed at the end of the buffer.
-        // We're essentially ditching temp points.
+        // We use size() instead of the index end because temp points might have been
+        // placed at the end of the buffer. Those temp points on this view are discarded,
+        // as are any on the temp list.
         auto thisEnd = m_index.begin() + size();
         auto bufEnd = buf.m_index.begin() + buf.size();
         m_index.insert(thisEnd, buf.m_index.begin(), bufEnd);
         m_size += buf.size();
-        clearTemps();
     }
 
     /// Return a new point view with the same point table as this
@@ -114,27 +110,111 @@ public:
     }
 
     PointRef point(PointId id)
-        { return PointRef(*this, id); }
+    {
+        if (id == m_index.size())
+            addPoint();
+        return PointRef(*this, id);
+    }
 
     template<class T>
     T getFieldAs(Dimension::Id dim, PointId pointIndex) const;
 
-    inline void getField(char *pos, Dimension::Id d,
-        Dimension::Type type, PointId id) const;
+    // Get value, converting to type 'type' and storing into 'pos'.
+    void getField(char *pos, Dimension::Id d, Dimension::Type type, PointId id) const
+    {
+        Everything e;
+
+        switch (type)
+        {
+            case Dimension::Type::Float:
+                e.f = getFieldAs<float>(d, id);
+                break;
+            case Dimension::Type::Double:
+                e.d = getFieldAs<double>(d, id);
+                break;
+            case Dimension::Type::Signed8:
+                e.s8 = getFieldAs<int8_t>(d, id);
+                break;
+            case Dimension::Type::Signed16:
+                e.s16 = getFieldAs<int16_t>(d, id);
+                break;
+            case Dimension::Type::Signed32:
+                e.s32 = getFieldAs<int32_t>(d, id);
+                break;
+            case Dimension::Type::Signed64:
+                e.s64 = getFieldAs<int64_t>(d, id);
+                break;
+            case Dimension::Type::Unsigned8:
+                e.u8 = getFieldAs<uint8_t>(d, id);
+                break;
+            case Dimension::Type::Unsigned16:
+                e.u16 = getFieldAs<uint16_t>(d, id);
+                break;
+            case Dimension::Type::Unsigned32:
+                e.u32 = getFieldAs<uint32_t>(d, id);
+                break;
+            case Dimension::Type::Unsigned64:
+                e.u64 = getFieldAs<uint64_t>(d, id);
+                break;
+            case Dimension::Type::None:
+                break;
+        }
+        memcpy(pos, &e, Dimension::size(type));
+    }
 
     template<typename T>
     void setField(Dimension::Id dim, PointId idx, T val);
 
-    inline void setField(Dimension::Id dim, Dimension::Type type,
-        PointId idx, const void *val);
-
-    template <typename T>
-    bool compare(Dimension::Id dim, PointId id1, PointId id2)
+    // Set value of type 'type' pointed to by 'val'.
+    void setField(Dimension::Id dim, Dimension::Type type, PointId idx, const void *val)
     {
-        return (getFieldInternal<T>(dim, id1) < getFieldInternal<T>(dim, id2));
+        Everything e;
+
+        memcpy(&e, val, Dimension::size(type));
+        switch (type)
+        {
+            case Dimension::Type::Float:
+                setField(dim, idx, e.f);
+                break;
+            case Dimension::Type::Double:
+                setField(dim, idx, e.d);
+                break;
+            case Dimension::Type::Signed8:
+                setField(dim, idx, e.s8);
+                break;
+            case Dimension::Type::Signed16:
+                setField(dim, idx, e.s16);
+                break;
+            case Dimension::Type::Signed32:
+                setField(dim, idx, e.s32);
+                break;
+            case Dimension::Type::Signed64:
+                setField(dim, idx, e.s64);
+                break;
+            case Dimension::Type::Unsigned8:
+                setField(dim, idx, e.u8);
+                break;
+            case Dimension::Type::Unsigned16:
+                setField(dim, idx, e.u16);
+                break;
+            case Dimension::Type::Unsigned32:
+                setField(dim, idx, e.u32);
+                break;
+            case Dimension::Type::Unsigned64:
+                setField(dim, idx, e.u64);
+                break;
+            case Dimension::Type::None:
+                break;
+        }
     }
 
-    bool compare(Dimension::Id dim, PointId id1, PointId id2)
+    template <typename T>
+    bool compare(Dimension::Id dim, PointId id1, PointId id2) const
+    {
+        return (getFieldAs<T>(dim, id1) < getFieldAs<T>(dim, id2));
+    }
+
+    bool compare(Dimension::Id dim, PointId id1, PointId id2) const
     {
         const Dimension::Detail *dd = layout()->dimDetail(dim);
 
@@ -177,25 +257,8 @@ public:
         }
     }
 
-    void getRawField(Dimension::Id dim, PointId idx, void *buf) const
-    {
-        getFieldInternal(dim, idx, buf);
-    }
-
-    /*! @return a cumulated bounds of all points in the PointView.
-        \verbatim embed:rst
-        .. note::
-
-            This method requires that an `X`, `Y`, and `Z` dimension be
-            available, and that it can be casted into a *double* data
-            type using the :cpp:func:`pdal::Dimension::applyScaling`
-            method. Otherwise, an exception will be thrown.
-        \endverbatim
-    */
     void calculateBounds(BOX2D& box) const;
-    static void calculateBounds(const PointViewSet&, BOX2D& box);
     void calculateBounds(BOX3D& box) const;
-    static void calculateBounds(const PointViewSet&, BOX3D& box);
 
     void dump(std::ostream& ostr) const;
     bool hasDim(Dimension::Id id) const
@@ -213,9 +276,9 @@ public:
     DimTypeList dimTypes() const
         { return layout()->dimTypes(); }
     PointLayoutPtr layout() const
-        { return m_pointTable.layout(); }
-    void setSpatialReference(const SpatialReference& spatialRef)
-        { m_spatialReference = spatialRef; }
+        { return m_layout; }
+    PointTableRef table() const
+        { return m_pointTable;}
     SpatialReference spatialReference() const
         { return m_spatialReference; }
 
@@ -227,7 +290,7 @@ public:
     {
         for (auto di = dims.begin(); di != dims.end(); ++di)
         {
-            getField(buf, di->m_id, di->m_type, idx);
+            m_pointTable.getFieldInternal(di->m_id, m_index[idx], buf);
             buf += Dimension::size(di->m_type);
         }
     }
@@ -239,9 +302,11 @@ public:
     /// \param[in] buf   Packed data buffer.
     void setPackedPoint(const DimTypeList& dims, PointId idx, const char *buf)
     {
+        if (idx == m_index.size())
+            addPoint();
         for (auto di = dims.begin(); di != dims.end(); ++di)
         {
-            setField(di->m_id, di->m_type, idx, (const void *)buf);
+            m_pointTable.setFieldInternal(di->m_id, idx, (const void *)buf);
             buf += Dimension::size(di->m_type);
         }
     }
@@ -259,22 +324,15 @@ public:
         {
             m_index.push_back(m_pointTable.addPoint());
             ++m_size;
-            assert(m_temps.empty());
         }
 
         return m_pointTable.getPoint(m_index.at(id));
     }
 
-    // The standard idiom is swapping with a stack-created empty queue, but
-    // that invokes the ctor and probably allocates.  We've probably only got
-    // one or two things in our queue, so just pop until we're empty.
-    void clearTemps()
-    {
-        while (!m_temps.empty())
-            m_temps.pop();
-    }
     MetadataNode toMetadata() const;
 
+    void invalidateProducts();
+
     /**
       Creates a mesh with the specified name.
 
@@ -292,39 +350,65 @@ public:
     */
     TriangularMesh *mesh(const std::string& name = "");
 
+    /**
+      Creates a raster with the specified name.
+
+      \param name  Name of the raster.
+      \param limits  Limits of the raster to create.
+      \return  Pointer to the new raster.  Null is returned if the raster already exists.
+    */
+    Rasterd *createRaster(const std::string& name, const RasterLimits& limits,
+        double noData = 0);
+
+    /**
+      Get a pointer to a raster.
+
+      \param name  Name of the raster.
+      \return  Pointer to the New raster. Null
+    */
+    Rasterd *raster(const std::string& name = "");
+
     KD3Index& build3dIndex();
     KD2Index& build2dIndex();
 
 protected:
     PointTableRef m_pointTable;
+    PointLayoutPtr m_layout;
     std::deque<PointId> m_index;
     // The index might be larger than the size to support temporary point
     // references.
     point_count_t m_size;
     int m_id;
-    std::queue<PointId> m_temps;
     SpatialReference m_spatialReference;
     std::map<std::string, std::unique_ptr<TriangularMesh>> m_meshes;
+    std::map<std::string, std::unique_ptr<Rasterd>> m_rasters;
     std::unique_ptr<KD3Index> m_index3;
     std::unique_ptr<KD2Index> m_index2;
 
 private:
     static int m_lastId;
 
-    template<typename T_IN, typename T_OUT>
-    bool convertAndSet(Dimension::Id dim, PointId idx, T_IN in);
+    PointId tableId(PointId idx)
+        { return idx >= size() ? 0 : m_index[idx]; }
 
-    virtual void setFieldInternal(Dimension::Id dim, PointId idx,
-        const void *buf);
-    virtual void getFieldInternal(Dimension::Id dim, PointId idx,
-        void *buf) const
-    { m_pointTable.getFieldInternal(dim, m_index[idx], buf); }
+    PointId addPoint();
+    void swapItems(PointId id1, PointId id2)
+    {
+        PointId temp = m_index[id2];
+        m_index[id2] = m_index[id1];
+        m_index[id1] = temp;
+    }
+    void setTableId(PointId dst, PointId tableId)
+    {
+        m_index[dst] = tableId;
+    }
 
-    template<class T>
-    T getFieldInternal(Dimension::Id dim, PointId pointIndex) const;
-    inline PointId getTemp(PointId id);
-    void freeTemp(PointId id)
-        { m_temps.push(id); }
+    void setSpatialReference(const SpatialReference& spatialRef)
+        { m_spatialReference = spatialRef; }
+
+    // For testing only.
+    PointId index(PointId id) const
+        { return m_index[id]; }
 };
 
 struct PointViewLess
@@ -334,154 +418,76 @@ struct PointViewLess
 };
 
 template <class T>
-T PointView::getFieldInternal(Dimension::Id dim, PointId id) const
-{
-    T t;
-
-    getFieldInternal(dim, id, &t);
-    return t;
-}
-
-inline void PointView::getField(char *pos, Dimension::Id d,
-    Dimension::Type type, PointId id) const
-{
-    Everything e;
-
-    switch (type)
-    {
-    case Dimension::Type::Float:
-        e.f = getFieldAs<float>(d, id);
-        break;
-    case Dimension::Type::Double:
-        e.d = getFieldAs<double>(d, id);
-        break;
-    case Dimension::Type::Signed8:
-        e.s8 = getFieldAs<int8_t>(d, id);
-        break;
-    case Dimension::Type::Signed16:
-        e.s16 = getFieldAs<int16_t>(d, id);
-        break;
-    case Dimension::Type::Signed32:
-        e.s32 = getFieldAs<int32_t>(d, id);
-        break;
-    case Dimension::Type::Signed64:
-        e.s64 = getFieldAs<int64_t>(d, id);
-        break;
-    case Dimension::Type::Unsigned8:
-        e.u8 = getFieldAs<uint8_t>(d, id);
-        break;
-    case Dimension::Type::Unsigned16:
-        e.u16 = getFieldAs<uint16_t>(d, id);
-        break;
-    case Dimension::Type::Unsigned32:
-        e.u32 = getFieldAs<uint32_t>(d, id);
-        break;
-    case Dimension::Type::Unsigned64:
-        e.u64 = getFieldAs<uint64_t>(d, id);
-        break;
-    case Dimension::Type::None:
-        break;
-    }
-    memcpy(pos, &e, Dimension::size(type));
-}
-
-inline void PointView::setField(Dimension::Id dim,
-    Dimension::Type type, PointId idx, const void *val)
-{
-    Everything e;
-
-    memcpy(&e, val, Dimension::size(type));
-    switch (type)
-    {
-        case Dimension::Type::Float:
-            setField(dim, idx, e.f);
-            break;
-        case Dimension::Type::Double:
-            setField(dim, idx, e.d);
-            break;
-        case Dimension::Type::Signed8:
-            setField(dim, idx, e.s8);
-            break;
-        case Dimension::Type::Signed16:
-            setField(dim, idx, e.s16);
-            break;
-        case Dimension::Type::Signed32:
-            setField(dim, idx, e.s32);
-            break;
-        case Dimension::Type::Signed64:
-            setField(dim, idx, e.s64);
-            break;
-        case Dimension::Type::Unsigned8:
-            setField(dim, idx, e.u8);
-            break;
-        case Dimension::Type::Unsigned16:
-            setField(dim, idx, e.u16);
-            break;
-        case Dimension::Type::Unsigned32:
-            setField(dim, idx, e.u32);
-            break;
-        case Dimension::Type::Unsigned64:
-            setField(dim, idx, e.u64);
-            break;
-        case Dimension::Type::None:
-            break;
-    }
-}
-
-template <class T>
-inline T PointView::getFieldAs(Dimension::Id dim,
-    PointId pointIndex) const
+inline T PointView::getFieldAs(Dimension::Id dim, PointId pointIndex) const
 {
     assert(pointIndex < m_size);
     T retval;
-    const Dimension::Detail *dd = layout()->dimDetail(dim);
-    double val;
+    bool ok = false;
+    const Dimension::Detail *dd = m_layout->dimDetail(dim);
+    Everything e;
 
+    PointId tableIdx = m_index[pointIndex];
+    // Note that getFieldInternal() can't be hoisted out of the switch
+    // because we don't want to call it in the case where the dimension
+    // type isn't known.  A separate test could be made, but that *might*
+    // cost and this is an important code path.
     switch (dd->type())
     {
     case Dimension::Type::Float:
-        val = getFieldInternal<float>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.f, retval);
         break;
     case Dimension::Type::Double:
-        val = getFieldInternal<double>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.d, retval);
         break;
     case Dimension::Type::Signed8:
-        val = getFieldInternal<int8_t>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.s8, retval);
         break;
     case Dimension::Type::Signed16:
-        val = getFieldInternal<int16_t>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.s16, retval);
         break;
     case Dimension::Type::Signed32:
-        val = getFieldInternal<int32_t>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.s32, retval);
         break;
     case Dimension::Type::Signed64:
-        val = static_cast<double>(getFieldInternal<int64_t>(dim, pointIndex));
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.s64, retval);
         break;
     case Dimension::Type::Unsigned8:
-        val = getFieldInternal<uint8_t>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.u8, retval);
         break;
     case Dimension::Type::Unsigned16:
-        val = getFieldInternal<uint16_t>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.u16, retval);
         break;
     case Dimension::Type::Unsigned32:
-        val = getFieldInternal<uint32_t>(dim, pointIndex);
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.u32, retval);
         break;
     case Dimension::Type::Unsigned64:
-        val = static_cast<double>(getFieldInternal<uint64_t>(dim, pointIndex));
+        m_pointTable.getFieldInternal(dim, tableIdx, &e);
+        ok = Utils::numericCast(e.u64, retval);
         break;
     case Dimension::Type::None:
     default:
-        val = 0;
+        ok = true;
+        retval = 0;
         break;
-    }
+    } // switch
 
-    if (!Utils::numericCast(val, retval))
+    if (!ok)
     {
         std::ostringstream oss;
         oss << "Unable to fetch data and convert as requested: ";
         oss << Dimension::name(dim) << ":" <<
             Dimension::interpretationName(dd->type()) <<
-            "(" << (double)val << ") -> " << Utils::typeidName<T>();
+            "(" << Utils::toDouble(e, dd->type()) << ") -> " <<
+            Utils::typeidName<T>();
         throw pdal_error(oss.str());
     }
 
@@ -489,61 +495,55 @@ inline T PointView::getFieldAs(Dimension::Id dim,
 }
 
 
-template<typename T_IN, typename T_OUT>
-bool PointView::convertAndSet(Dimension::Id dim, PointId idx, T_IN in)
-{
-    T_OUT out;
-
-    bool success = Utils::numericCast(in, out);
-    if (success)
-        setFieldInternal(dim, idx, &out);
-    return success;
-}
-
-
 template<typename T>
 void PointView::setField(Dimension::Id dim, PointId idx, T val)
 {
     const Dimension::Detail *dd = layout()->dimDetail(dim);
 
+    Everything e;
     bool ok = true;
     switch (dd->type())
     {
     case Dimension::Type::Float:
-        ok = convertAndSet<T, float>(dim, idx, val);
+        ok = Utils::numericCast(val, e.f);
         break;
     case Dimension::Type::Double:
-        ok = convertAndSet<T, double>(dim, idx, val);
+        ok = Utils::numericCast(val, e.d);
         break;
     case Dimension::Type::Signed8:
-        ok = convertAndSet<T, int8_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.s8);
         break;
     case Dimension::Type::Signed16:
-        ok = convertAndSet<T, int16_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.s16);
         break;
     case Dimension::Type::Signed32:
-        ok = convertAndSet<T, int32_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.s32);
         break;
     case Dimension::Type::Signed64:
-        ok = convertAndSet<T, int64_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.s64);
         break;
     case Dimension::Type::Unsigned8:
-        ok = convertAndSet<T, uint8_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.u8);
         break;
     case Dimension::Type::Unsigned16:
-        ok = convertAndSet<T, uint16_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.u16);
         break;
     case Dimension::Type::Unsigned32:
-        ok = convertAndSet<T, uint32_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.u32);
         break;
     case Dimension::Type::Unsigned64:
-        ok = convertAndSet<T, uint64_t>(dim, idx, val);
+        ok = Utils::numericCast(val, e.u64);
         break;
     case Dimension::Type::None:
-        val = 0;
-        break;
+        return;
     }
-    if (!ok)
+    if (ok)
+    {
+        if (idx == m_index.size())
+            addPoint();
+        m_pointTable.setFieldInternal(dim, tableId(idx), &e);
+    }
+    else
     {
         std::ostringstream oss;
         oss << "Unable to set data and convert as requested: ";
@@ -557,31 +557,72 @@ void PointView::setField(Dimension::Id dim, PointId idx, T val)
 inline void PointView::appendPoint(const PointView& buffer, PointId id)
 {
     // Invalid 'id' is a programmer error.
-    PointId rawId = buffer.m_index[id];
-    m_index.push_back(rawId);
+    m_index.push_back(buffer.m_index[id]);
     m_size++;
-    assert(m_temps.empty());
 }
 
 
-// Make a temporary copy of a point by adding an entry to the index.
-inline PointId PointView::getTemp(PointId id)
+PDAL_EXPORT std::ostream& operator<<(std::ostream& ostr, const PointView&);
+
+// PointViewIter
+
+class PointViewIter
 {
-    PointId newid;
-    if (m_temps.size())
-    {
-        newid = m_temps.front();
-        m_temps.pop();
-        m_index[newid] = m_index[id];
-    }
-    else
-    {
-        newid = (PointId)m_index.size();
-        m_index.push_back(m_index[id]);
-    }
-    return newid;
-}
+private:
+    PointView *m_view;
+    PointId m_id;
 
-PDAL_DLL std::ostream& operator<<(std::ostream& ostr, const PointView&);
+public:
+    using iterator_category = std::random_access_iterator_tag;
+    using value_type = PointRef;
+    using difference_type = ptrdiff_t;
+    using pointer = PointRef*;
+    using reference = PointRef;
+
+    PointViewIter()
+    {}
+    PointViewIter(PointView* view, PointId id) : m_view(view), m_id(id)
+    {}
+
+    PointViewIter& operator++()
+        { m_id++; return *this; }
+    PointViewIter operator++(int)
+        { return PointViewIter(m_view, m_id++); }
+    PointViewIter& operator--()
+        { --m_id; return *this; }
+    PointViewIter operator--(int)
+        { return PointViewIter(m_view, m_id--); }
+
+    PointViewIter operator+(const difference_type& n) const
+        { return PointViewIter(m_view, m_id + n); }
+    PointViewIter operator+=(const difference_type& n)
+        { m_id += n; return *this; }
+    PointViewIter operator-(const difference_type& n) const
+        { return PointViewIter(m_view, m_id - n); }
+    PointViewIter operator-=(const difference_type& n)
+        { m_id -= n; return *this; }
+    difference_type operator-(const PointViewIter& i) const
+        { return static_cast<difference_type>(m_id - i.m_id); }
+
+    bool operator==(const PointViewIter& i) const
+        { return m_id == i.m_id; }
+    bool operator!=(const PointViewIter& i) const
+        { return m_id != i.m_id; }
+    bool operator<(const PointViewIter& i) const
+        { return m_id < i.m_id; }
+    bool operator<=(const PointViewIter& i) const
+        { return m_id <= i.m_id; }
+    bool operator>(const PointViewIter& i) const
+        { return m_id > i.m_id; }
+    bool operator>=(const PointViewIter& i) const
+        { return m_id >= i.m_id; }
+
+    reference operator*() const
+        { return PointRef(*m_view, m_id); }
+    pointer operator->()
+        { return nullptr; }
+    reference operator[](const difference_type& n) const
+        { return PointRef(*m_view, m_id + n); }
+};
 
 } // namespace pdal
